@@ -43,11 +43,14 @@
 #include <QtCore/qdebug.h>
 #include <QtCore/qdatastream.h>
 #include <QtCore/qeventloop.h>
+#include <QtCore/qloggingcategory.h>
 #include <QtCore/qscopedvaluerollback.h>
 #include <QtCore/qtimer.h>
 
 QT_BEGIN_NAMESPACE
 
+Q_LOGGING_CATEGORY(QT_CANBUS, "qt.canbus")
+
 /*!
     \class QCanBusDevice
     \inmodule QtSerialBus
@@ -113,6 +116,7 @@ QT_BEGIN_NAMESPACE
                             CAN FD allows to transmit the payload of frames with
                             \l QCanBusFrame::hasBitrateSwitch() flag at a higher data bitrate,
                             after the arbitration phase at the nominal bitrate is finished.
+                            This enum value was introduced in Qt 5.9.
                             See also \c QCanBusDevice::BitRateKey
     \value UserKey          This key defines the range where custom keys start. Its most
                             common purpose is to permit platform-specific configuration
@@ -206,9 +210,9 @@ QT_BEGIN_NAMESPACE
 */
 
 /*!
-    \fn QCanBusDevice::errorOccurred(CanBusError error)
+    \fn void QCanBusDevice::errorOccurred(CanBusError)
 
-    This signal is emitted when an error of the type \a error occurs.
+    This signal is emitted when an error occurs.
 */
 
 /*!
@@ -445,10 +449,10 @@ bool QCanBusDevice::waitForFramesWritten(int msecs)
 {
     // do not enter this function recursively
     if (Q_UNLIKELY(d_func()->waitForWrittenEntered)) {
-        qWarning("QCanBusDevice::waitForFramesWritten() must not be called "
-                 "recursively. Check that no slot containing waitForFramesReceived() "
-                 "is called in response to framesWritten(qint64) or errorOccurred(CanBusError)"
-                 "signals\n");
+        qCWarning(QT_CANBUS, "QCanBusDevice::waitForFramesWritten() must not be called "
+                             "recursively. Check that no slot containing waitForFramesReceived() "
+                             "is called in response to framesWritten(qint64) or "
+                             "errorOccurred(CanBusError) signals.");
         return false;
     }
 
@@ -498,10 +502,10 @@ bool QCanBusDevice::waitForFramesReceived(int msecs)
 {
     // do not enter this function recursively
     if (Q_UNLIKELY(d_func()->waitForReceivedEntered)) {
-        qWarning("QCanBusDevice::waitForFramesReceived() must not be called "
-                 "recursively. Check that no slot containing waitForFramesReceived() "
-                 "is called in response to framesReceived() or errorOccurred(CanBusError) "
-                 "signals\n");
+        qCWarning(QT_CANBUS, "QCanBusDevice::waitForFramesReceived() must not be called "
+                             "recursively. Check that no slot containing waitForFramesReceived() "
+                             "is called in response to framesReceived() or "
+                             "errorOccurred(CanBusError) signals.");
         return false;
     }
 
@@ -672,7 +676,7 @@ void QCanBusDevice::disconnectDevice()
 
     if (Q_UNLIKELY(d->state == QCanBusDevice::UnconnectedState
             || d->state == QCanBusDevice::ClosingState)) {
-        qWarning("Can not disconnect an unconnected device");
+        qCWarning(QT_CANBUS, "Can not disconnect an unconnected device.");
         return;
     }
 
@@ -723,11 +727,28 @@ void QCanBusDevice::setState(QCanBusDevice::CanBusDeviceState newState)
  */
 QCanBusDeviceInfo QCanBusDevice::createDeviceInfo(const QString &name, bool isVirtual,
                                                   bool isFlexibleDataRateCapable)
+{
+    return createDeviceInfo(name, QString(), QString(), 0, isVirtual, isFlexibleDataRateCapable);
+}
+
+/*!
+    \since 5.11
+    Returns a QCanBusDeviceInfo created from the given parameters \a name,
+    \a serialNumber, \a description, \a channel, \a isVirtual, and \a
+    isFlexibleDataRateCapable.
+    \internal
+ */
+QCanBusDeviceInfo QCanBusDevice::createDeviceInfo(const QString &name, const QString &serialNumber,
+                                                  const QString &description, int channel,
+                                                  bool isVirtual, bool isFlexibleDataRateCapable)
 {
     QScopedPointer<QCanBusDeviceInfoPrivate> info(new QCanBusDeviceInfoPrivate);
     info->name = name;
-    info->isVirtual = isVirtual;
+    info->serialNumber = serialNumber;
+    info->description = description;
+    info->channel = channel;
     info->hasFlexibleDataRate = isFlexibleDataRateCapable;
+    info->isVirtual = isVirtual;
     return QCanBusDeviceInfo(*info.take());
 }
 
